.. This file is a part of the AnyBlok / Pyramid project
..
..    Copyright (C) 2018 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

Bloks
=====

Blok Auth
---------

.. automodule:: anyblok_pyramid.bloks.auth
.. autoclass:: Auth
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok_pyramid/bloks/auth/README.rst
.. include:: ../anyblok_pyramid/bloks/auth/CODE.rst

Blok Password
-------------

.. automodule:: anyblok_pyramid.bloks.password
.. autoclass:: Password
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok_pyramid/bloks/password/README.rst
.. include:: ../anyblok_pyramid/bloks/password/CODE.rst

Blok Authorization
------------------

.. automodule:: anyblok_pyramid.bloks.authorization
.. autoclass:: Authorization
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok_pyramid/bloks/authorization/README.rst
.. include:: ../anyblok_pyramid/bloks/authorization/CODE.rst
